# CometChatCall Flutter Plugin

![](https://assets-global.website-files.com/5f3c19f18169b65d9d0bf384/61fa9da6582eb93036b07cda_horizontal%20primary.svg)

[![Latest version of 'cometchatcalls_plugin' @ Cloudsmith](https://api-prd.cloudsmith.io/v1/badges/version/cometchat/call-team/dart/cometchatcalls_plugin/latest/a=noarch/?render=true&show_latest=true)](https://cloudsmith.io/~cometchat/repos/call-team/packages/detail/dart/cometchatcalls_plugin/latest/a=noarch/)

### Features

- Direct Call
- Default Call
- Calling v3 support
- Support Android platform
- Support iOS platform

### Integrate CometChat Flutter Calls Plugin

#### 1. Setup
- SDK Version <= 2.14
  <br>
  A dependency may be manually added to your project pubspec.yaml:
  <p>
  dependencies:<br>
  &nbsp;&nbsp;cometchatcalls_plugin:<br>
  &nbsp;&nbsp;&nbsp;&nbsp;hosted:<br>
  &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;name: cometchatcalls_plugin<br>
  &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;url: https://dart.cloudsmith.io/cometchat/call-team/<br>
  &nbsp;&nbsp;&nbsp;&nbsp;version: 1.0.1<br>
  </p>

- SDK Version >= 2.15
  dart pub is capable of adding a dependency from this repository to your package pubspec.yaml automatically:
`dart pub add cometchatcalls_plugin:1.0.1 --hosted-url https://dart.cloudsmith.io/cometchat/call-team/
`


#### 2. Configure CometChat Flutter Calls Plugin inside your Flutter app
###### i. Import CometChatCall
`import 'package:cometchatcalls_plugin/cometchatcalls.dart';
`

###### ii. Initialize CometChatCalls
```dart
CallAppSettings callAppSettings= (CallAppSettingBuilder()
  ..appId = AppConfig.appId
  ..region= AppConfig.region	        
  //..host = ""
).build();

CometChatCalls.init(callAppSettings, onSuccess: (String successMessage) {
  debugPrint("===>>>: Initialization completed successfully  $successMessage");
}, onError: (CometChatCallsException e) {	  
  debugPrint("===>>>: Initialization failed with exception: ${e.message}");
});
```
###### iii. Generate Call Token
```dart
CometChatCalls.generateToken("sessionId", "userAuthToken", onSuccess: (GenerateToken generateToken){
  debugPrint("===>>>: generateToken success: ${generateToken.token}");
}, onError: (CometChatCallsException e){	  
  debugPrint("===>>>: generateToken Error: $e");
});
```

###### iv. Start call session
```dart
MainVideoContainerSetting videoSettings = MainVideoContainerSetting();
videoSettings.setVideoStreamProp("contain");
videoSettings.setNameLabelProps("top-left", true, "#000");
videoSettings.setZoomButtonProps("top-right", true);
videoSettings.setUserListButtonProps("top-left", true);
videoSettings.setFullScreenButtonProps("top-right", true);

CallSettings callSettings= (CallSettingsBuilder()
  ..defaultLayout = true
  ..videoSettings = videoSettings
  ..listener = this
).build();

CometChatCalls.startSession("generatedToken", callSettings, onSuccess: (Widget? callingWidget){
  debugPrint("===>>>: startCallSession success");
}, onError: (CometChatCallsException e){	  
  debugPrint("===>>>: startCallSession Error: $e");
});
```


###### v. Call settings　

- End Session
```dart
CometChatCalls.endSession(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: endSession: success $success");
  Navigator.pop(context);
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: endSession: error $error");
});
```

- Switch Camera
```dart
CometChatCalls.switchCamera(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: switchCamera: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: switchCamera: error $error");
});
```

- Mute Audio
```dart
CometChatCalls.muteAudio(true ,onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: muteAudio: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: muteAudio: error $error");
});
```

- Pause Video
```dart
CometChatCalls.pauseVideo(true, onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: pauseVideo: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: pauseVideo:error $error");
});
```

- Set Audio Mode
```dart
CometChatCalls.setAudioMode("", onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: setAudioMode: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: setAudioMode: error $error");
});
```

- Enter PIP Mode
```dart
CometChatCalls.enterPIPMode(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: enterPIPMode: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: enterPIPMode: error $error");
});
```

- Exit PIP Mode
```dart
CometChatCalls.exitPIPMode(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: exitPIPMode: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: exitPIPMode: error $error");
});
```

- Switch to Video Call
```dart
CometChatCalls.switchToVideoCall(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: switchToVideoCall: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: switchToVideoCall: error $error");
});
```

- Start Recording
```dart
CometChatCalls.startRecording(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: startRecording: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: startRecording: error $error");
});
```

- Stop Recording
```dart
CometChatCalls.stopRecording(onSuccess: (success) {
  debugPrint("===>>>: callingOtherSettings: stopRecording: success $success");
}, onError: (error) {
  debugPrint("===>>>: callingOtherSettings: stopRecording: error $error");
});
```




